@@ -1,5 +1,5 @@
 /*
- * Copyright (c) OSGi Alliance (2004, 2015). All Rights Reserved.
+ * Copyright (c) OSGi Alliance (2004, 2018). All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -48,7 +48,7 @@ import java.util.List;
  * anywhere else but in the beginning of a URI.</li>
  * </ul>
  * 
- * @author $Id: 7ab4cc1cb063d03c00a40ca138697a922905368f $
+ * @author $Id: 96c835ffcb87dd71ffc8104ff7f1ce049c8a9539 $
  */
 public final class Uri {
 
@@ -122,7 +122,7 @@ public final class Uri {
 	 * length of the name does exceed the limit, the following mechanism is used
 	 * to normalize it:
 	 * <ul>
-	 * <li>the SHA 1 digest of the name is calculated</li>
+	 * <li>the SHA-1 digest of the name is calculated</li>
 	 * <li>the digest is encoded with the base 64 algorithm</li>
 	 * <li>all '/' characters in the encoded digest are replaced with '_'</li>
 	 * <li>trailing '=' signs are removed</li>
@@ -158,7 +158,7 @@ public final class Uri {
 			return "";
 		}
 
-		StringBuffer uri = new StringBuffer();
+		StringBuilder uri = new StringBuilder();
 		for (int i = 0; i < path.length; ++i) {
 			if (i > 0) {
 				uri.append('/');
@@ -191,7 +191,7 @@ public final class Uri {
 		if (segment.length() == 0)
 			throw new IllegalArgumentException("URI segment is empty.");
 
-		StringBuffer newsegment = new StringBuffer(segment);
+		StringBuilder newsegment = new StringBuilder(segment);
 		int i = 0;
 		while (i < newsegment.length()) { // length can decrease during the
 											// loop!
@@ -241,8 +241,8 @@ public final class Uri {
 		if (uri.length() == 0)
 			return new String[] {};
 
-		List segments = new ArrayList();
-		StringBuffer segment = new StringBuffer();
+		List<String> segments = new ArrayList<>();
+		StringBuilder segment = new StringBuilder();
 
 		boolean escape = false;
 		for (int i = 0; i < uri.length(); i++) {
@@ -256,7 +256,7 @@ public final class Uri {
 			} else
 				if (ch == '/') {
 					segments.add(segment.toString());
-					segment = new StringBuffer();
+				segment = new StringBuilder();
 				} else
 					if (ch == '\\') {
 						escape = true;
@@ -267,7 +267,7 @@ public final class Uri {
 			segments.add(segment.toString());
 		}
 
-		return (String[]) segments.toArray(new String[segments.size()]);
+		return segments.toArray(new String[0]);
 	}
 
 	/**
@@ -306,7 +306,7 @@ public final class Uri {
 			if (c == '\\' || c == '/') {
 				// We've got an to be escaped character, so now create the
 				// string buffer
-				StringBuffer sb = new StringBuffer(nodeName);
+				StringBuilder sb = new StringBuilder(nodeName);
 				for (; i < sb.length(); i++) {
 					c = sb.charAt(i);
 					if (c == '\\' || c == '/')
@@ -333,7 +333,7 @@ public final class Uri {
 		if (n < 0)
 			return nodeName;
 
-		StringBuffer sb = new StringBuffer(nodeName);
+		StringBuilder sb = new StringBuilder(nodeName);
 		while (n >= 0 && n < sb.length()) {
 			sb.deleteCharAt(n);
 			n++;
@@ -416,7 +416,7 @@ public final class Uri {
 			return getHash(nodeName);
 
 		// escape any '/' and '\' characters in the node name
-		StringBuffer nameBuffer = new StringBuffer(nodeName);
+		StringBuilder nameBuffer = new StringBuilder(nodeName);
 		for (int i = 0; i < nameBuffer.length(); i++)
 			// 'i' can increase in loop
 			if (nameBuffer.charAt(i) == '\\' || nameBuffer.charAt(i) == '/')
@@ -444,7 +444,7 @@ public final class Uri {
 		// very dumb base64 encoder code. There is no need for multiple lines
 		// or trailing '='-s....
 		// also, we hardcoded the fact that sha-1 digests are 20 bytes long
-		StringBuffer sb = new StringBuffer(digest.length * 2);
+		StringBuilder sb = new StringBuilder(digest.length * 2);
 		for (int i = 0; i < 6; i++) {
 			int d0 = digest[i * 3] & 0xff;
 			int d1 = digest[i * 3 + 1] & 0xff;
